@@ -1,10 +1,9 @@
 package Test::RDF;
 
-use 5.006;
 use warnings;
 use strict;
 
-use Carp qw(confess);
+use Carp;
 use RDF::Trine;
 use RDF::Trine::Parser;
 use RDF::Trine::Model;
@@ -12,7 +11,7 @@ use RDF::Trine::Graph;
 use Scalar::Util qw/blessed/;
 
 use base 'Test::Builder::Module';
-our @EXPORT = qw/are_subgraphs is_rdf is_valid_rdf isomorph_graphs has_subject has_predicate has_object_uri has_type has_uri hasnt_uri has_literal hasnt_literal pattern_target pattern_ok pattern_fail/;
+our @EXPORT = qw/are_subgraphs is_rdf is_valid_rdf isomorph_graphs has_subject has_predicate has_object_uri has_uri hasnt_uri has_literal pattern_target pattern_ok pattern_fail/;
 
 
 =head1 NAME
@@ -21,11 +20,11 @@ Test::RDF - Test RDF data for content, validity and equality, etc.
 
 =head1 VERSION
 
-Version 1.21_01
+Version 1.10
 
 =cut
 
-our $VERSION = '1.21_01';
+our $VERSION = '1.10';
 
 
 =head1 SYNOPSIS
@@ -41,9 +40,7 @@ our $VERSION = '1.21_01';
  has_subject($uri_string, $model, 'Subject URI is found');
  has_predicate($uri_string, $model, 'Predicate URI is found');
  has_object_uri($uri_string, $model, 'Object URI is found');
- has_type($uri_string, $model, 'Class URI is found');
  has_literal($string, $language, $datatype, $model, 'Literal is found');
- hasnt_literal($string, $language, $datatype, $model, 'Literal is not found');
  pattern_target($model);
  pattern_ok($pattern, '$pattern found in $model');
  pattern_fail($pattern, '$pattern not found in $model');
@@ -136,8 +133,6 @@ Use to check if the input RDF::Trine::Models have isomorphic graphs.
 
 sub isomorph_graphs {
   my ($model1, $model2, $name) = @_;
-  confess 'No valid models given in test' unless ((blessed($model1) && $model1->isa('RDF::Trine::Model'))
-																	&& (blessed($model2) && $model2->isa('RDF::Trine::Model')));
   my $g1 = RDF::Trine::Graph->new( $model1 );
   my $g2 = RDF::Trine::Graph->new( $model2 );
   my $test = __PACKAGE__->builder;
@@ -161,8 +156,6 @@ Use to check if the first RDF::Trine::Models is a subgraph of the second.
 
 sub are_subgraphs {
   my ($model1, $model2, $name) = @_;
-  confess 'No valid models given in test' unless ((blessed($model1) && $model1->isa('RDF::Trine::Model'))
-																	&& (blessed($model2) && $model2->isa('RDF::Trine::Model')));
   my $g1 = RDF::Trine::Graph->new( $model1 );
   my $g2 = RDF::Trine::Graph->new( $model2 );
   my $test = __PACKAGE__->builder;
@@ -187,10 +180,7 @@ of the statements given in the model given as second argument.
 
 sub has_subject {
   my ($uri, $model, $name) = @_;
-  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
-  my $resource = _resource_uri_checked($uri, $name);
-  return $resource unless ($resource);
-  my $count = $model->count_statements($resource, undef, undef);
+  my $count = $model->count_statements(RDF::Trine::Node::Resource->new($uri), undef, undef);
   return _single_uri_tests($count, $name);
 }
 
@@ -204,10 +194,7 @@ of the statements given in the model given as second argument.
 
 sub has_predicate {
   my ($uri, $model, $name) = @_;
-  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
-  my $resource = _resource_uri_checked($uri, $name);
-  return $resource unless ($resource);
-  my $count = $model->count_statements(undef, $resource, undef);
+  my $count = $model->count_statements(undef, RDF::Trine::Node::Resource->new($uri), undef);
   return _single_uri_tests($count, $name);
 }
 
@@ -220,30 +207,7 @@ of the statements given in the model given as second argument.
 
 sub has_object_uri {
   my ($uri, $model, $name) = @_;
-  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
-  my $resource = _resource_uri_checked($uri, $name);
-  return $resource unless ($resource);
-  my $count = $model->count_statements(undef, undef, $resource);
-  return _single_uri_tests($count, $name);
-}
-
-
-=head2 has_type
-
-Check if the string URI passed as first argument is an RDF class
-instance in any of the statements given in the model given as second
-argument.
-
-=cut
-
-sub has_type {
-  my ($uri, $model, $name) = @_;
-  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
-  my $resource = _resource_uri_checked($uri, $name);
-  return $resource unless ($resource);
-  my $count = $model->count_statements(undef,
-													RDF::Trine::Node::Resource->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#type'),
-													$resource);
+  my $count = $model->count_statements(undef, undef, RDF::Trine::Node::Resource->new($uri));
   return _single_uri_tests($count, $name);
 }
 
@@ -272,7 +236,6 @@ and a language literal like
 
 sub has_literal {
   my ($string, $lang, $datatype, $model, $name) = @_;
-  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
   my $literal;
   my $test = __PACKAGE__->builder;
   eval {
@@ -284,6 +247,7 @@ sub has_literal {
     return;
   }
 
+  #local $Test::Builder::Level = $Test::Builder::Level + 1;
   if ($model->count_statements(undef, undef, $literal) > 0) {
     $test->ok( 1, $name );
     return 1;
@@ -295,41 +259,6 @@ sub has_literal {
 }
 
 
-=head2 hasnt_literal
-
-This is like the above, only the opposite: It checks if a literal
-doesn't exist. Like the above, the test will fail if the literal is
-invalid, however.
-
-=cut
-
-sub hasnt_literal {
-  my ($string, $lang, $datatype, $model, $name) = @_;
-  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
-  my $literal;
-  my $test = __PACKAGE__->builder;
-  eval {
-    $literal = RDF::Trine::Node::Literal->new($string, $lang, $datatype);
-  };
-
-  if ( my $error = $@ ) {
-    $test->ok( 0, $name );
-    $test->diag("Invalid literal:\n\n\t$error");
-    return;
-  }
-
-  if ($model->count_statements(undef, undef, $literal) > 0) {
-    $test->ok( 0, $name );
-    $test->diag('Matching literals found in model');
-    return 0;
-  } else {
-    $test->ok( 1, $name );
-    return 1;
-  }
-}
-
-
-
 =head2 has_uri
 
 Check if the string URI passed as first argument is present in any of
@@ -339,13 +268,10 @@ the statements given in the model given as second argument.
 
 sub has_uri {
   my ($uri, $model, $name) = @_;
-  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
   my $test = __PACKAGE__->builder;
-  my $resource = _resource_uri_checked($uri, $name);
-  return $resource unless ($resource);
-  if ($model->count_statements(undef, undef, $resource) > 0
-      || $model->count_statements(undef, $resource, undef) > 0
-      || $model->count_statements($resource, undef, undef) > 0) {
+  if ($model->count_statements(undef, undef, RDF::Trine::Node::Resource->new($uri)) > 0
+      || $model->count_statements(undef, RDF::Trine::Node::Resource->new($uri), undef) > 0
+      || $model->count_statements(RDF::Trine::Node::Resource->new($uri), undef, undef) > 0) {
     $test->ok( 1, $name );
     return 1;
   } else {
@@ -365,15 +291,10 @@ of the statements given in the model given as second argument.
 
 sub hasnt_uri {
   my ($uri, $model, $name) = @_;
-  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
   my $test = __PACKAGE__->builder;
-  my $resource;
-  eval {
-	  $resource = RDF::Trine::Node::Resource->new($uri);
-  };
-  if (($resource) && ($model->count_statements(undef, undef, $resource) > 0
-      || $model->count_statements(undef, $resource, undef) > 0
-      || $model->count_statements($resource, undef, undef)) > 0) {
+  if ($model->count_statements(undef, undef, RDF::Trine::Node::Resource->new($uri)) > 0
+      || $model->count_statements(undef, RDF::Trine::Node::Resource->new($uri), undef) > 0
+      || $model->count_statements(RDF::Trine::Node::Resource->new($uri), undef, undef) > 0) {
     $test->ok( 0, $name );
     $test->diag('Matching URIs found in model');
     return 0;
@@ -398,26 +319,6 @@ sub _single_uri_tests {
   }
 }
 
-sub _resource_uri_checked {
-	my ($uri, $name) = @_;
-	my $resource;
-	eval {
-		$resource = RDF::Trine::Node::Resource->new($uri);
-	};
-	if ( my $error = $@ ) {
-		my $test = __PACKAGE__->builder;
-		local $Test::Builder::Level = $Test::Builder::Level + 1;
-		$test->ok( 0, $name );
-		$test->diag("No matching URIs found in model");
-		return 0;
-	}
-	return $resource;
-}
-
-		
-
-
-
 =head2 pattern_target
 
 Tests that the object passed as its parameter is an RDF::Trine::Model or
@@ -612,8 +513,7 @@ Toby Inkster has submitted the pattern_* functions.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 ABC Startsiden AS.
-Copyright 2010, 2011, 2012, 2013, 2014, 2015, 2017 Kjetil Kjernsmo.
+Copyright 2010 ABC Startsiden AS and 2010-2012 Kjetil Kjernsmo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
